/***************************************************************************
*   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation version 2.1.                *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU Lesser General Public      *
*   License along with this library; if not, write to the                 *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA              *
***************************************************************************/
#ifndef BITFIELDTYPE_H
#define BITFIELDTYPE_H

#include <string>

#include <bit/enums.h>

namespace bit {

/**
	@author Rick L. Vinyard, Jr. <rvinyard@cs.nmsu.edu>
*/
class FieldType{
public:

  FieldType(Type type=TYPE_NONE, ByteOrder byte_order=BYTEORDER_NETWORK, Sign sign=SIGN_UNSIGNED);

    ~FieldType();

    Type type() const;
    void set_type(Type);
    const char* type_string() const;

    ByteOrder byte_order() const;
    void set_byte_order(ByteOrder);
    const char* byte_order_string() const;

    Sign sign() const;
    void set_sign(Sign);
    const char* sign_string() const;

    static const char* type_string(Type);
    static const char* byte_order_string(ByteOrder);
    static const char* sign_string(Sign);

  bool operator==(const FieldType& other) const;

  bool operator!=(const FieldType& other) const;

  const std::string& xml();

  protected:
    Type m_type;
    ByteOrder m_byte_order;
    Sign m_sign;
    std::string m_xml;

    static const char* m_type_string[];
    static const char* m_byte_order_string[];
    static const char* m_sign_string[];
};

}

#endif
